package com.ruoyi.system.service.columns;

import com.ruoyi.system.domain.columns.SysTeacher;

import java.util.List;

/**
 * 员工信息Service接口
 * 
 * @author ruoyi
 * @date 2025-10-28
 */
public interface ISysTeacherService 
{
    /**
     * 查询员工信息
     *
     * @param userId 员工信息主键
     * @return 员工信息
     */
    public SysTeacher selectSysTeacherByUserId(Long userId);

    /**
     * 查询员工信息列表
     * 
     * @param sysTeacher 员工信息
     * @return 员工信息集合
     */
    public List<SysTeacher> selectSysTeacherList(SysTeacher sysTeacher);

    /**
     * 新增员工信息
     * 
     * @param sysTeacher 员工信息
     * @return 结果
     */
    public int insertSysTeacher(SysTeacher sysTeacher);

    /**
     * 修改员工信息
     * 
     * @param sysTeacher 员工信息
     * @return 结果
     */
    public int updateSysTeacher(SysTeacher sysTeacher);

    /**
     * 批量删除员工信息
     * 
     * @param userIds 需要删除的员工信息主键集合
     * @return 结果
     */
    public int deleteSysTeacherByUserIds(Long[] userIds);

    /**
     * 删除员工信息信息
     * 
     * @param userId 员工信息主键
     * @return 结果
     */
    public int deleteSysTeacherByUserId(Long userId);
}
